@@ -5,17 +5,18 @@ use Mojo::Base 'Mojolicious';
 use Carp;
 use File::ShareDir ':ALL';
 use Path::Tiny;
+use Class::Load ':all';
 
-our $VERSION = '0.011_14';
+our $VERSION = '0.014_01';
 
 has admin_menu => sub {
   my $self = shift;
-  return +{};
+  return [];
 };
 
 has frontend_menu => sub {
   my $self = shift;
-  return +{};
+  return [];
 };
 
 sub startup {
@@ -26,7 +27,7 @@ sub startup {
 ###############################################################################
     my $cfgfile = undef;
     if ($self->mode eq "development") {
-        $cfgfile = path(dist_dir('App-skryf'), 'skryf.conf');
+        $cfgfile = path(dist_dir('App-skryf'), 'app/config/development.conf');
     }
     else {
         $cfgfile = path("~/.skryf.conf");
@@ -35,14 +36,27 @@ sub startup {
     }
     $self->plugin('Config' => {file => $cfgfile});
     my $cfg = $self->config->{skryf} || +{};
-    $cfg->{version} = $VERSION;
+    $cfg->{version} = eval $VERSION;
     $self->secret($cfg->{secret});
+
+###############################################################################
+# Database Helper
+###############################################################################
+    $self->helper(
+        db => sub {
+            my $self       = shift;
+            my $collection = shift;
+            my $store      = "App::skryf::Model::$collection";
+            load_class($store);
+            $store->new(dbname => $cfg->{dbname});
+        }
+    );
 ###############################################################################
 # Load global plugins
 ###############################################################################
     push @{$self->plugins->namespaces}, 'App::skryf::Plugin';
     for (keys $cfg->{extra_modules}) {
-        $self->plugin("$_") if $cfg->{extra_modules}{$_} > 0;
+        $self->plugin($_) if $cfg->{extra_modules}{$_} > 0;
     }
 
 ###############################################################################
@@ -62,8 +76,8 @@ sub startup {
     my $media_directory    = undef;
     if ($self->mode eq "development" || !defined($cfg->{template_directory}))
     {
-        $template_directory = path(dist_dir('App-skryf'), 'templates');
-        $media_directory    = path(dist_dir('App-skryf'), 'public');
+        $template_directory = path(dist_dir('App-skryf'), 'app/templates');
+        $media_directory    = path(dist_dir('App-skryf'), 'app/public');
     }
     else {
         $template_directory = path($cfg->{template_directory});
@@ -87,11 +101,12 @@ sub startup {
     my $r = $self->routes;
 
     # Authentication
+    # TODO: make pluggable
     $r->get('/login')->to('login#login')->name('login');
     $r->get('/logout')->to('login#logout')->name('logout');
     $r->post('/auth')->to('login#auth')->name('auth');
 
-    # Todo make splashpage overridable
+    # TODO: make splashpage overridable
     $r->get('/')->to(
         namespace => 'App::skryf::Plugin::Blog::Controller',
         action    => 'blog_splash'
